import React, { lazy, Suspense } from 'react';
import { BrowserRouter as Router, Routes, Route } from 'react-router-dom';
import { HelmetProvider } from 'react-helmet-async';
import Header from './components/Header';
import Footer from './components/Footer';
import ScrollToTop from './components/ScrollToTop';

// Lazy load pages for better performance
const HomePage = lazy(() => import('./pages/HomePage'));
const TalkToHana = lazy(() => import('./pages/TalkToHana'));
const HanaCoach = lazy(() => import('./pages/HanaCoach'));
const CompassLandingPage = lazy(() => import('./pages/CompassLandingPage'));
const AboutPage = lazy(() => import('./pages/AboutPage'));
const ChronicCare = lazy(() => import('./pages/ChronicCare'));
const BehavioralHealth = lazy(() => import('./pages/BehavioralHealth'));
const TransitionalCare = lazy(() => import('./pages/TransitionalCare'));
const PopulationOutreach = lazy(() => import('./pages/PopulationOutreach'));
const ContactPage = lazy(() => import('./pages/ContactPage'));
const BlogPage = lazy(() => import('./pages/BlogPage'));
const BlogCategoryPage = lazy(() => import('./pages/BlogCategoryPage'));
const BlogArticle = lazy(() => import('./pages/BlogArticle'));
const BlogArticleEdit = lazy(() => import('./pages/BlogArticleEdit'));
const CommunityPage = lazy(() => import('./pages/CommunityPage'));
const DemoAccountPage = lazy(() => import('./pages/DemoAccountPage'));
const VapiChatPage = lazy(() => import('./pages/VapiChatPage'));
const TermsOfServicePage = lazy(() => import('./pages/TermsOfServicePage'));
const PrivacyPolicyPage = lazy(() => import('./pages/PrivacyPolicyPage'));
const PreferencesPage = lazy(() => import('./pages/PreferencesPage'));

// Loading component for suspense fallback
const PageLoader = () => (
  <div className="min-h-screen flex items-center justify-center bg-white">
    <div className="animate-pulse flex flex-col items-center">
      <div className="h-16 w-16 bg-hana-green-900/20 rounded-full mb-4"></div>
      <div className="h-4 w-32 bg-hana-green-900/20 rounded"></div>
    </div>
  </div>
);

const DefaultLayout: React.FC<{ children: React.ReactNode }> = ({ children }) => (
  <>
    <Header />
    <main className="pt-20 sm:pt-24">
      {children}
    </main>
    <Footer />
  </>
);

function App() {
  return (
    <Router>
      <ScrollToTop />
      <HelmetProvider>
        <div className="min-h-screen bg-white text-slate-900 transition-colors duration-300 overflow-x-hidden">
          <Suspense fallback={<PageLoader />}>
            <Routes>
              {/* Routes without default layout */}
              <Route path="/talk-to-hana" element={<TalkToHana />} />
              
              {/* Routes with default layout */}
              <Route path="/" element={<DefaultLayout><HomePage /></DefaultLayout>} />
              <Route path="/hana-coach" element={<DefaultLayout><HanaCoach /></DefaultLayout>} />
              <Route path="/hana-compass" element={<DefaultLayout><CompassLandingPage /></DefaultLayout>} />
              <Route path="/about" element={<DefaultLayout><AboutPage /></DefaultLayout>} />
              <Route path="/chronic-care" element={<DefaultLayout><ChronicCare /></DefaultLayout>} />
              <Route path="/behavioral-health" element={<DefaultLayout><BehavioralHealth /></DefaultLayout>} />
              <Route path="/transitional-care" element={<DefaultLayout><TransitionalCare /></DefaultLayout>} />
              <Route path="/population-outreach" element={<DefaultLayout><PopulationOutreach /></DefaultLayout>} />
              <Route path="/contact" element={<DefaultLayout><ContactPage /></DefaultLayout>} />
              <Route path="/blog" element={<DefaultLayout><BlogPage /></DefaultLayout>} />
              <Route path="/blog/category/:categorySlug" element={<DefaultLayout><BlogCategoryPage /></DefaultLayout>} />
              <Route path="/blog/:slug" element={<DefaultLayout><BlogArticle /></DefaultLayout>} />
              <Route path="/blog/:slug/edit" element={<DefaultLayout><BlogArticleEdit /></DefaultLayout>} />
              <Route path="/community" element={<DefaultLayout><CommunityPage /></DefaultLayout>} />
              <Route path="/demo-account" element={<DefaultLayout><DemoAccountPage /></DefaultLayout>} />
              <Route path="/voice-chat" element={<DefaultLayout><VapiChatPage /></DefaultLayout>} />
              <Route path="/terms-of-service" element={<DefaultLayout><TermsOfServicePage /></DefaultLayout>} />
              <Route path="/privacy-policy" element={<DefaultLayout><PrivacyPolicyPage /></DefaultLayout>} />
              <Route path="/preferences" element={<DefaultLayout><PreferencesPage /></DefaultLayout>} />
              
              {/* 404 route */}
              <Route path="*" element={
                <DefaultLayout>
                  <div className="container mx-auto px-4 py-16 text-center">
                    <h1 className="text-4xl font-bold text-hana-green-900 mb-4">Page Not Found</h1>
                    <p className="text-gray-700">The page you're looking for doesn't exist.</p>
                  </div>
                </DefaultLayout>
              } />
            </Routes>
          </Suspense>
        </div>
      </HelmetProvider>
    </Router>
  );
}

// Export with React.memo for better performance
export default React.memo(App);